package com.ynet.life.loaf;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.jdbc.DataTypeConfig;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/* loaded from: com_ynet_life_loaf.jar:com/ynet/life/loaf/TableConfigXMLReader.class */
public class TableConfigXMLReader {
    private static final String XML_TAG_ITEM_ID = "businessCode";
    private static final String XML_TAG_SUB_BSNCODE = "subBusinessCode";
    private static final String XML_TAG_SHOW_BSNCODE = "showBusinessCode";
    private static final String XML_TAG_TABLE_NAME = "tableName";
    private static final String XML_TAG_CONFIG_FIELD = "configField";
    private static final String XML_TAG_REF_CONFIG = "refConfig";
    private static final String XML_TAG_REF_ID = "refId";
    private static final String XML_TAG_DATA_FIELD = "dataField";
    private static final String XML_TAG_TABLE_FIELD = "tableField";
    private static final String XML_TAG_PRIMARY_KEY = "isPrimaryKey";
    private static final String XML_TAG_JOINED_KEY = "isJoinedKey";
    private static final String XML_TAG_SEARCH_KEY = "isSearchKey";
    private static final String XML_TAG_DATA_TYPE = "dataType";
    private static final String XML_TAG_CONTEXT_FIELD = "contextField";
    private Node rootNode;

    public TableConfigXMLReader(String fileName) {
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setValidating(false);
            NodeList list = factory.newDocumentBuilder().parse(new File(fileName)).getChildNodes();
            for (int i = 0; i < list.getLength(); i++) {
                if (list.item(i) instanceof Element) {
                    this.rootNode = list.item(i);
                    return;
                }
            }
        } catch (Exception ex) {
            Trace.logError("LOAF", "读入配置文件失败", ex);
        }
    }

    public Map getConfigs() throws TranFailException {
        Map configs = new HashMap();
        Map refConfig = new HashMap();
        NodeList configNodeList = this.rootNode.getChildNodes().item(1).getChildNodes();
        int size = configNodeList.getLength();
        for (int i = 0; i < size; i++) {
            Node node = configNodeList.item(i);
            if (node.getNodeType() == 1) {
                Node itemIdNode = node.getAttributes().getNamedItem(XML_TAG_ITEM_ID);
                Node subBusinessNode = node.getAttributes().getNamedItem(XML_TAG_SUB_BSNCODE);
                Node showBusinessNode = node.getAttributes().getNamedItem(XML_TAG_SHOW_BSNCODE);
                Node tableNameNode = node.getAttributes().getNamedItem(XML_TAG_TABLE_NAME);
                if (itemIdNode != null && tableNameNode != null) {
                    String businessCode = itemIdNode.getNodeValue().trim();
                    String subBusinessCode = subBusinessNode == null ? null : subBusinessNode.getNodeValue().trim();
                    String showBusinessCode = showBusinessNode == null ? null : showBusinessNode.getNodeValue().trim();
                    String tableName = tableNameNode.getNodeValue();
                    TableConfig newConfig = new TableConfig(businessCode, tableName, subBusinessCode, showBusinessCode);
                    NodeList fieldNodeList = node.getChildNodes();
                    int languageNodeSize = fieldNodeList.getLength();
                    for (int j = 0; j < languageNodeSize; j++) {
                        Node child = fieldNodeList.item(j);
                        if (child.getNodeType() == 1) {
                            if (child.getNodeName().equals(XML_TAG_CONFIG_FIELD)) {
                                addConfigField(newConfig, child);
                            } else if (child.getNodeName().equals(XML_TAG_REF_CONFIG)) {
                                Node refNode = child.getAttributes().getNamedItem(XML_TAG_REF_ID);
                                int index = businessCode.indexOf(",");
                                if (index > 0) {
                                    refConfig.put(businessCode.substring(0, index), refNode.getNodeValue());
                                } else {
                                    refConfig.put(businessCode, refNode.getNodeValue());
                                }
                            }
                        }
                    }
                    String[] codes = businessCode.split(",");
                    for (String str : codes) {
                        configs.put(str, newConfig);
                    }
                }
            }
        }
        for (Map.Entry entry : refConfig.entrySet()) {
            String businessCode2 = (String) entry.getKey();
            String refBusinessCode = (String) entry.getValue();
            TableConfig tableConfig = (TableConfig) configs.get(businessCode2);
            List fields = getRefConfigs(configNodeList, refBusinessCode);
            for (int i2 = 0; i2 < fields.size(); i2++) {
                addConfigField(tableConfig, (Node) fields.get(i2));
            }
        }
        return configs;
    }

    public List getRefConfigs(NodeList configNodeList, String businessCode) {
        Node configNode = null;
        int size = configNodeList.getLength();
        for (int i = 0; i < size; i++) {
            Node item = configNodeList.item(i);
            configNode = item;
            if (item != null && configNode.getNodeType() == 1) {
                Node itemIdNode = configNode.getAttributes().getNamedItem(XML_TAG_ITEM_ID);
                if (containsBusinessCode(itemIdNode.getNodeValue(), businessCode)) {
                    break;
                }
            }
        }
        NodeList fieldNodeList = configNode.getChildNodes();
        int fieldNodeSize = fieldNodeList.getLength();
        List refConfigs = new ArrayList();
        for (int j = 0; j < fieldNodeSize; j++) {
            Node child = fieldNodeList.item(j);
            if (child.getNodeType() == 1) {
                if (child.getNodeName().equals(XML_TAG_CONFIG_FIELD)) {
                    refConfigs.add(child);
                } else if (child.getNodeName().equals(XML_TAG_REF_CONFIG)) {
                    Node refNode = child.getAttributes().getNamedItem(XML_TAG_REF_ID);
                    refConfigs.addAll(getRefConfigs(configNodeList, refNode.getNodeValue()));
                }
            }
        }
        return refConfigs;
    }

    private boolean containsBusinessCode(String parentBusinessCode, String childBusinessCode) {
        boolean flag = false;
        String[] businessCodes = parentBusinessCode.split(",");
        int i = 0;
        while (true) {
            if (i >= businessCodes.length) {
                break;
            }
            if (!businessCodes[i].trim().equals(childBusinessCode)) {
                i++;
            } else {
                flag = true;
                break;
            }
        }
        return flag;
    }

    public void addConfigField(TableConfig newConfig, Node configFieldNode) throws TranFailException {
        Node dataFieldNode = configFieldNode.getAttributes().getNamedItem(XML_TAG_DATA_FIELD);
        Node tableFieldNode = configFieldNode.getAttributes().getNamedItem(XML_TAG_TABLE_FIELD);
        Node isPrimaryKeyNode = configFieldNode.getAttributes().getNamedItem(XML_TAG_PRIMARY_KEY);
        Node isJoinedKeyNode = configFieldNode.getAttributes().getNamedItem(XML_TAG_JOINED_KEY);
        Node dataTypeNode = configFieldNode.getAttributes().getNamedItem(XML_TAG_DATA_TYPE);
        Node contextFiledNode = configFieldNode.getAttributes().getNamedItem(XML_TAG_CONTEXT_FIELD);
        Node searchFiledNode = configFieldNode.getAttributes().getNamedItem(XML_TAG_SEARCH_KEY);
        String dataFieldName = getNode(dataFieldNode);
        String tableFieldName = getNode(tableFieldNode);
        String isPrimaryKey = getNode(isPrimaryKeyNode);
        String isJoinedKey = getNode(isJoinedKeyNode);
        String dataType = getNode(dataTypeNode);
        String contextFiled = getNode(contextFiledNode);
        String isSearchKey = getNode(searchFiledNode);
        if (dataFieldName == null || tableFieldName == null) {
            Trace.logError("LOAF", "数据字段名[" + dataFieldName + "]或者表字段名[" + tableFieldName + "]为空");
            throw new TranFailException("EBLN0000", "数据字段名[" + dataFieldName + "]或者表字段名[" + tableFieldName + "]为空");
        }
        newConfig.addDataTableField(dataFieldName, tableFieldName, isPrimaryKey, isJoinedKey, contextFiled, isSearchKey);
        if (dataType != null) {
            DataTypeConfig.addField(newConfig.getTableName(), tableFieldName, dataType);
        }
    }

    private String getNode(Node dataFieldNode) {
        if (dataFieldNode == null) {
            return null;
        }
        return dataFieldNode.getNodeValue();
    }
}
